# Little Wire Python library

<p align="center">
  <a href="https://github.com/tiacsys/verylittlewire/actions?query=workflow%3ACI">
    <img src="https://img.shields.io/github/workflow/status/tiacsys/verylittlewire/CI/main?label=CI&logo=github&style=flat-square" alt="CI Status" >
  </a>
  <a href="https://verylittlewire.readthedocs.io">
    <img src="https://img.shields.io/readthedocs/verylittlewire.svg?logo=read-the-docs&logoColor=fff&style=flat-square" alt="Documentation Status">
  </a>
  <a href="https://codecov.io/gh/tiacsys/verylittlewire">
    <img src="https://img.shields.io/codecov/c/github/tiacsys/verylittlewire.svg?logo=codecov&logoColor=fff&style=flat-square" alt="Test coverage percentage">
  </a>
</p>
<p align="center">
  <a href="https://python-poetry.org/">
    <img src="https://img.shields.io/badge/packaging-poetry-299bd7?style=flat-square&logo=data:image/png;base64, " alt="Poetry">
  </a>
  <a href="https://github.com/ambv/black">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square" alt="black">
  </a>
  <a href="https://github.com/pre-commit/pre-commit">
    <img src="https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white&style=flat-square" alt="pre-commit">
  </a>
</p>
<p align="center">
  <a href="https://pypi.org/project/verylittlewire/">
    <img src="https://img.shields.io/pypi/v/verylittlewire.svg?logo=python&logoColor=fff&style=flat-square" alt="PyPI Version">
  </a>
  <img src="https://img.shields.io/pypi/pyversions/verylittlewire.svg?style=flat-square&logo=python&amp;logoColor=fff" alt="Supported Python versions">
  <img src="https://img.shields.io/pypi/l/verylittlewire.svg?style=flat-square" alt="License">
</p>

The Little Wire Python library provides an interface to the Little Wire USB Multi-Tool developed by Ihsan Kehribar.

## Installation

Install this via pip (or your favourite package manager):

`pip install verylittlewire`

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- prettier-ignore-start -->
<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="http://www.li-pro.net/stephan-linz.phtml"><img src="https://avatars.githubusercontent.com/u/5664060?v=4?s=80" width="80px;" alt="Stephan Linz"/><br /><sub><b>Stephan Linz</b></sub></a><br /><a href="https://github.com/tiacsys/verylittlewire/commits?author=rexut" title="Code">💻</a> <a href="#ideas-rexut" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/tiacsys/verylittlewire/commits?author=rexut" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/adajoh99"><img src="https://avatars.githubusercontent.com/u/1729678?v=4?s=80" width="80px;" alt="Adam Johnson"/><br /><sub><b>Adam Johnson</b></sub></a><br /><a href="https://github.com/tiacsys/verylittlewire/commits?author=adajoh99" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://soundcloud.com/ihsankehribar/sets/bits-and-pieces"><img src="https://avatars.githubusercontent.com/u/360652?v=4?s=80" width="80px;" alt="Ihsan Kehribar"/><br /><sub><b>Ihsan Kehribar</b></sub></a><br /><a href="#ideas-kehribar" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://omer.kilic.name/"><img src="https://avatars.githubusercontent.com/u/9847?v=4?s=80" width="80px;" alt="Omer Kilic"/><br /><sub><b>Omer Kilic</b></sub></a><br /><a href="#ideas-omerk" title="Ideas, Planning, & Feedback">🤔</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->
<!-- prettier-ignore-end -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

## Credits

This package was created with
[Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[browniebroke/cookiecutter-pypackage](https://github.com/browniebroke/cookiecutter-pypackage)
project template.
